// xmpp-client: A sample GTK client in Rust
// Copyright (C) 2024 Link Mauve <linkmauve@linkmauve.fr>
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

mod imp;

use adw::subclass::prelude::*;
use gtk::{gio, glib};

glib::wrapper! {
    pub struct MainWindow(ObjectSubclass<imp::MainWindow>)
        @extends gtk::Widget, gtk::Window, gtk::ApplicationWindow, adw::ApplicationWindow,
        @implements gio::ActionMap, gio::ActionGroup;
}

impl MainWindow {
    pub fn new(app: &adw::Application) -> Self {
        glib::Object::builder().property("application", app).build()
    }

    pub fn split_view(&self) -> &adw::NavigationSplitView {
        &self.imp().split_view
    }

    pub fn tabs(&self) -> &gtk::ListView {
        &self.imp().tabs_list
    }

    pub fn messages(&self) -> &gtk::ListView {
        &self.imp().message_list_view
    }

    pub fn selection(&self) -> &gtk::NoSelection {
        &self.imp().selection
    }

    pub fn tabs_selection(&self) -> &gtk::SingleSelection {
        &self.imp().tabs_selection
    }

    pub fn entry(&self) -> &gtk::Entry {
        &self.imp().entry
    }
}
